#
# spec file for package tmpwatch
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tmpwatch
Summary:        Watches file system activity, such as /tmp files
License:        GPL-2.0-only
Group:          Productivity/Security
Version:        2.11
Release:        7.7
URL:            https://pagure.io/tmpwatch
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}.service
Source2:        %{name}.timer
Source3:        %{name}-autoclean
BuildRequires:  psmisc
Requires:       psmisc

%description
The tmpwatch utility recursively searches through specified directories
and removes files which have not been accessed in a specified period of
time. tmpwatch is normally used to clean up directories which are used
for temporarily holding files (for example, /tmp).

There are multiple tools called "tmpwatch", this package contains the
Fedora/Red Hat version previously available at
https://fedorahosted.org/tmpwatch and now hosted at
https://pagure.io/tmpwatch

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
install -D -m 0644 %{SOURCE1} %{buildroot}/%{_unitdir}/%{name}.service
install -D -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/%{name}.timer
install -D -m 0755 %{SOURCE3} %{buildroot}/%{_sbindir}/%{name}-autoclean

%pre
%service_add_pre %{name}.service %{name}.timer

%post
%service_add_post tmpwatch.service tmpwatch.timer

%preun
%service_del_preun %{name}.service %{name}.timer

%postun
%service_del_postun %{name}.service %{name}.timer

%files
%defattr(-,root,root)
%doc ChangeLog NEWS README
%license COPYING
%{_sbindir}/%{name}
%{_sbindir}/%{name}-autoclean
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.timer
%{_mandir}/man8/%{name}.8*

%changelog
* Fri Oct 13 2023 Martin Jungblut Schreiner <martinjungblut@gmail.com>
- Remove tmpwatch.daily cron script, replace it with systemd timer.
- Remove cron as a dependency.
- Add tmpwatch.service, tmpwatch.timer, rename tmpwatch.daily as
  /usr/sbin/tmpwatch-autoclean. The systemd timer/service triggers
  this newly named script.
- This change is related to bsc#1115430.
* Wed Aug 21 2019 Jan Engelhardt <jengelh@inai.de>
- The cron software is not required for building the tmpwatch
  proper; avoid pulling it in and ship cron file directories.
- Enable parallel build. Upgrade old macros.
* Tue Aug 20 2019 kukuk@suse.de
- Add cron as BuildRequires for directory layout
* Wed Mar 20 2019 ro@suse.de
- update the homepage url
* Wed Nov 19 2014 Led <ledest@gmail.com>
- fix bashisms in tmpwatch.daily cron script
* Sun Feb  2 2014 cfarrell@suse.com
- license update: GPL-2.0
  See e.g. tmpwatch.c - tell upstream about this
* Thu Jan 23 2014 aj@ajaissle.de
- use %%{_sysconfdir} for /etc
* Fri Aug 10 2012 chris@computersalat.de
- update to 2.11
  * INCOMPATIBLE CHANGE: On Linux, sockets that are certainly unused
    are now removed by default.
- fix License to be in spdx format
  * GPL-2.0+
* Fri Sep 16 2011 coolo@suse.com
- update to 2.10.3
  * Don't report EACCES errors, they can be routinely returned by FUSE mounts.
  * Minor bug fixes in bind mount handling.
  * Don't follow (non-trivial) bind mounts.
  * Minor bug and documentation fixes.
* Wed Sep 14 2011 andrea.turrini@gmail.com
- fixed typos in tmpwatch.spec
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Fri Oct 22 2010 cristian.rodriguez@opensuse.org
- Use a _service instead of keeping a tarball
* Sat Apr 17 2010 crrodriguez@opensuse.org
- update to version 2.10.1
  * Only support fuser if it is available at build time.
  * Upstream migrated to autotools
* Tue Apr  8 2008 crrodriguez@suse.de
- tmpwatch declared GPLv2 only but has no COPYING file [bnc #377839]
* Mon Apr  7 2008 crrodriguez@suse.de
- adding fedora tmpwatch to openSUSE 11
- command tmpwatch does not exist, some man pages are still around [bnc #368527]
* Sun Mar  9 2008 crrodriguez@suse.de
- initial openSUSE package
